@@ -104,18 +104,6 @@ class ContentNode(object):
         return f"ContentNode [node_type:{self.node_type}] ({len(self.get_features())} features, {len(self.children)} children) [" + str(
             self.content) + "]"
 
-    def _repr_html_(self):
-        return self.to_html()
-
-    def to_html(self):
-        """
-        Generate HTML and javascript necessary for rendering this ContentNode.
-
-        :return:  HTML and javascript that will render this ContentNode
-        :rtype: str
-        """
-        return DocumentRender(self.document).render_node(self)
-
     def to_json(self):
         """
         Create a JSON string representation of this ContentNode.
@@ -611,6 +599,8 @@ class ContentNode(object):
 
         def tag_node_position(node_to_check, start, end, node_data):
 
+            content_length = 0
+
             # Make sure we have content on the node
             if node_to_check.content:
                 if len(node_to_check.content) > 0:
@@ -628,18 +618,20 @@ class ContentNode(object):
                                                       data=node_data))
 
                 end = end - len(node_to_check.content) + len(separator)
+                content_length = len(node_to_check.content) + len(separator)
                 start = 0 if start - len(node_to_check.content) - len(separator) < 0 else start - len(
                     node_to_check.content) - len(separator)
 
             for child_node in node_to_check.children:
                 result = tag_node_position(child_node, start, end, node_data)
+                content_length = content_length + result
                 if result < 0:
                     return -1
                 else:
                     end = end - result
                     start = 0 if start - result < 0 else start - result
 
-            return end
+            return content_length
 
         if content_re:
             pattern = re.compile(content_re)
@@ -1148,19 +1140,6 @@ class ContentFeature(object):
         return {'name': self.feature_type + ':' + self.name, 'value': self.value, 'single': self.single}
 
 
-class DocumentRender:
-
-    def __init__(self, document):
-        self.document = document
-        self.kodexa_render = KodexaRender()
-
-    def to_html(self):
-        return self.kodexa_render.build_html(self.document, self.document.content_node)
-
-    def render_node(self, node):
-        return self.kodexa_render.build_html(self.document, node)
-
-
 @dataclasses.dataclass()
 class SourceMetadata:
     """
@@ -1221,7 +1200,7 @@ class Document(object):
         """
         return self.content_node
 
-    def to_kdxa(self, file_path):
+    def to_kdxa(self, file_path: str):
         """
         Write the document to the kdxa format (msgpack) which can be
         used with the Kodexa platform
@@ -1265,18 +1244,6 @@ class Document(object):
         """
         return json.dumps(self.to_dict(), ensure_ascii=False)
 
-    def _repr_html_(self):
-        return self.to_html()
-
-    def to_html(self):
-        """
-        Generate HTML and javascript necessary for rendering this ContentNode.
-
-        :return:  HTML and javascript that will render this ContentNode
-        :rtype: str
-        """
-        return DocumentRender(self).to_html()
-
     def to_dict(self):
         """
         Create a dictionary representing this Document's structure and content.
@@ -1485,39 +1452,14 @@ class Document(object):
             return self.create_node(node_type='results')
 
 
-class KodexaRender:
-    KODEXA_JS_URL = 'https://cdn.jsdelivr.net/npm/kodexajs/kodexa'
+class DocumentStore:
+    """A document store supports storing, listing and retrieving Kodexa documents"""
 
-    """
-    An implementation of a render that uses the KodexaJS
-    library to render the document
+    def get(self, path: str) -> Document:
+        pass
 
-    See https://github.com/kodexa-ai/kodexa.js
-    """
+    def list(self) -> List[str]:
+        pass
 
-    def build_node_html(self, node: ContentNode):
-        self.build_html(node.document, node)
-
-    def build_html(self, document: Document, node: ContentNode):
-        render_uuid = str(uuid.uuid4())
-        return """
-  <div id='kodexa-div-""" + render_uuid + """'></div>
-  <script>
-
-require.config({
-    paths: {
-        'kodexa-lib-""" + render_uuid + """': '""" + KodexaRender.KODEXA_JS_URL + """',
-        'jquery': '//ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min'
-    }
-});
-
-require(['kodexa-lib-""" + render_uuid + """','jquery'], function() {
-    kodexa.fromMap(""" + document.to_json() + """).then(kdxaDocument => {
-       let widget = kodexa.newDocumentWidget(kdxaDocument);
-       widget.attach($('#kodexa-div-""" + render_uuid + """'))
-       widget.render(""" + ("'" + node.uuid + "'" if node else "") + """);
-    });
-
-});
-</script>
-"""
+    def put(self, path: str, document: Document):
+        pass
