@@ -17,8 +17,9 @@ from uuid import uuid4
 import yaml
 
 from kodexa.connectors import FolderConnector
-from kodexa.connectors.connectors import get_caller_dir, KodexaPlatformStore
+from kodexa.connectors.connectors import get_caller_dir
 from kodexa.model import Document, Store
+from kodexa.stores.stores import DocumentStore
 
 
 def new_id():
@@ -438,6 +439,19 @@ class Pipeline:
 
         return self
 
+    def to_store(self, document_store: DocumentStore):
+        """
+        Allows you to provide the sink store easily
+
+        This will wrap the store in a document store sink
+
+        :param document_store: document store to use
+        :return: the pipeline
+        """
+        from kodexa.sinks import DocumentStoreSink
+        self.set_sink(DocumentStoreSink(document_store))
+        return self
+
     def to_yaml(self):
         """
         Will return the YAML representation of any actions that support conversion to YAML
@@ -558,19 +572,6 @@ class Pipeline:
         return Pipeline(FolderConnector(folder_path, filename_filter, recursive=recursive, relative=relative,
                                         caller_path=caller_path, unpack=unpack))
 
-    @staticmethod
-    def from_store(org_slug: str, slug: str, query: str = "*") -> Pipeline:
-        """
-        Create a pipeline that will again the documents in a Kodexa platform store
-
-        :param org_slug: The organization's slug
-        :param slug: The store slug
-        :param query: A query to be applied (defaults to *)
-        :return: A new pipeline
-        :rtype: Pipeline
-        """
-        return Pipeline(KodexaPlatformStore(org_slug, slug, query))
-
 
 class PipelineStatistics:
     """
