@@ -6,5 +6,4 @@ Sinks are the end-point of a Pipeline and allow for the final output of the pipe
 out
 """
 from .inmemory import InMemoryDocumentSink
-from .cloud import KodexaPlatformSink
-from .local import FolderSink
+from .local import FolderSink, DocumentStoreSink
